pub enum PsramMode {
Hex,
}Available on crate feature
unstable only.Expand description
PSRAM interface mode (line count of the data bus).
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Variants
Hex
16-line DDR, AP HEX PSRAM with MR8.x16 = 1. Default.